==> grader-service-0.3.0.tar.gz: grader-service-0.3.0/grader_service/orm/assignment.py <==
# Copyright (c) 2022, TU Wien
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

import enum
import json
from datetime import datetime

from grader_service.api.models import assignment
from sqlalchemy import (Column, DateTime, Enum, ForeignKey,
                        Integer, String, Text, Boolean, DECIMAL)
from sqlalchemy.orm import relationship

from grader_service.orm.base import Base, DeleteState, Serializable


class AutoGradingBehaviour(enum.Enum):
    unassisted = 0  # assignments not automatically graded
    auto = 1  # assignments auto graded when submitted
    full_auto = 2  # assignments auto graded, feedback generated on submit


class Assignment(Base, Serializable):
    __tablename__ = "assignment"
    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String(255), nullable=False)
    """Name of the assignment"""
    type = Column(Enum("user", "group"), nullable=False, server_default="user")
    """Type of the assignment"""
    lectid = Column(Integer, ForeignKey("lecture.id"))
    duedate = Column(DateTime, nullable=False)
    points = Column(DECIMAL(10, 3), nullable=True)
    status = Column(
        Enum("created", "pushed", "released", "complete"),
        default="created",
    )
    automatic_grading = Column(Enum(AutoGradingBehaviour), nullable=False)
    deleted = Column(Enum(DeleteState), nullable=False, unique=False)
    max_submissions = Column(Integer, nullable=True,
                             default=None, unique=False)
    allow_files = Column(Boolean, nullable=False, default=False)
    properties = Column(Text, nullable=True, unique=False)
    created_at = Column(DateTime, default=datetime.utcnow, nullable=False)
    updated_at = Column(DateTime, default=datetime.utcnow,
                        onupdate=datetime.utcnow, nullable=False)
    settings = Column(Text, server_default='', nullable=False)

    lecture = relationship("Lecture", back_populates="assignments")
    submissions = relationship("Submission", back_populates="assignment")

    @property
    def model(self) -> assignment.Assignment:
        assignment_model = assignment.Assignment(
            id=self.id,
            name=self.name,
            due_date=None
            if self.duedate is None
            else (self.duedate.isoformat("T", "milliseconds") + "Z"),
            status=self.status,
            type=self.type,
            points=self.points,
            automatic_grading=self.automatic_grading.name,
            max_submissions=self.max_submissions,
            allow_files=self.allow_files,
            settings=assignment.AssignmentSettings.from_dict(json.loads(self.settings))
        )
        return assignment_model

==> grader-service-0.6.1.tar.gz: grader-service-0.6.1/grader_service/orm/assignment.py <==
# Copyright (c) 2022, TU Wien
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

import enum
import json
from datetime import datetime, timezone

from grader_service.api.models import assignment
from sqlalchemy import (Column, DateTime, Enum, ForeignKey,
                        Integer, String, Text, Boolean, DECIMAL)
from sqlalchemy.orm import relationship

from grader_service.orm.base import Base, DeleteState, Serializable


class AutoGradingBehaviour(enum.Enum):
    unassisted = 0  # assignments not automatically graded
    auto = 1  # assignments auto graded when submitted
    full_auto = 2  # assignments auto graded, feedback generated on submit
    
    @classmethod
    def get(cls, name):
        return cls.__members__.get(name, None)

def get_utc_time():
    return datetime.now(tz=timezone.utc)

class Assignment(Base, Serializable):
    __tablename__ = "assignment"
    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String(255), nullable=False)
    """Name of the assignment"""
    type = Column(Enum("user", "group"), nullable=False, server_default="user")
    """Type of the assignment"""
    lectid = Column(Integer, ForeignKey("lecture.id"))
    duedate = Column(DateTime, nullable=False)
    points = Column(DECIMAL(10, 3), nullable=True)
    status = Column(
        Enum("created", "pushed", "released", "complete"),
        default="created",
    )
    automatic_grading = Column(Enum(AutoGradingBehaviour), nullable=False)
    deleted = Column(Enum(DeleteState), nullable=False, unique=False)
    max_submissions = Column(Integer, nullable=True,
                             default=None, unique=False)
    allow_files = Column(Boolean, nullable=False, default=False)
    properties = Column(Text, nullable=True, unique=False)
    created_at = Column(DateTime, default=get_utc_time, nullable=False)
    updated_at = Column(DateTime, default=get_utc_time,
                        onupdate=get_utc_time, nullable=False)
    settings = Column(Text, server_default='', nullable=False)

    lecture = relationship("Lecture", back_populates="assignments")
    submissions = relationship("Submission", back_populates="assignment")

    @property
    def model(self) -> assignment.Assignment:
        assignment_model = assignment.Assignment(
            id=self.id,
            name=self.name,
            due_date=None
            if self.duedate is None
            else self.duedate,
            status=self.status,
            type=self.type,
            points=self.points,
            automatic_grading=self.automatic_grading.name,
            max_submissions=self.max_submissions,
            allow_files=self.allow_files,
            settings=assignment.AssignmentSettings.from_dict(json.loads(self.settings))
        )
        return assignment_model
